#
# spec file for package ghc-turtle
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%global pkg_name turtle

%bcond_with tests

Name:           ghc-turtle
Version:        1.2.8
Release:        1.2
Summary:        Shell programming, Haskell-style
Group:          System/Libraries

License:        BSD-3-Clause
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
# Begin cabal-rpm deps:
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-clock-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-foldl-devel
BuildRequires:  ghc-hostname-devel
BuildRequires:  ghc-managed-devel
BuildRequires:  ghc-optional-args-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-system-fileio-devel
BuildRequires:  ghc-system-filepath-devel
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unix-devel
%if %{with tests}
BuildRequires:  ghc-doctest-devel
%endif
# End cabal-rpm deps

%description
'turtle' is a reimplementation of the Unix command line environment in Haskell
so that you can use Haskell as both a shell and a scripting language.

Features include:

* Batteries included: Command an extended suite of predefined utilities

* Interoperability: You can still run external shell commands

* Portability: Works on Windows, OS X, and Linux

* Exception safety: Safely acquire and release resources

* Streaming: Transform or fold command output in constant space

* Patterns: Use typed regular expressions that can parse structured values

* Formatting: Type-safe 'printf'-style text formatting

* Modern: Supports 'text' and 'system-filepath'

Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
quick-start guide

'turtle' is designed to be beginner-friendly, but as a result lacks certain
features, like tracing commands. If you feel comfortable using 'turtle' then
you should also check out the 'Shelly' library which provides similar
functionality.


%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}
Requires:       %{name} = %{version}-%{release}

%description devel
This package provides the Haskell %{pkg_name} library development files.


%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build


%install
%ghc_lib_install


%check
%if %{with tests}
%cabal test
%endif


%post devel
%ghc_pkg_recache


%postun devel
%ghc_pkg_recache


%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE


%files devel -f %{name}-devel.files
%defattr(-,root,root,-)


%changelog
* Mon May 30 2016 mimi.vx@gmail.com
- update to 1.2.8
* Tue Apr 26 2016 mimi.vx@gmail.com
- update to 1.2.7
* Mon Apr  4 2016 mimi.vx@gmail.com
- update to 1.2.6
* Sun Jan 24 2016 mimi.vx@gmail.com
- initial commit
